# je_editor

---

[![Downloads](https://static.pepy.tech/badge/je-editor)](https://pepy.tech/project/je-editor)


[![Codacy Badge](https://app.codacy.com/project/badge/Grade/825a90622a224207be4abe869775b50a)](https://www.codacy.com/gh/JE-Chen/je_editor/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=JE-Chen/je_editor&amp;utm_campaign=Badge_Grade)

[![CircleCI](https://dl.circleci.com/status-badge/img/gh/Intergration-Automation-Testing/je_editor/tree/main.svg?style=svg)](https://dl.circleci.com/status-badge/redirect/gh/Intergration-Automation-Testing/je_editor/tree/main)

[![JE_Editor GitHub Actions Dev](https://github.com/JE-Chen/je_editor/actions/workflows/je-editor-github-actions_dev.yml/badge.svg?branch=dev)](https://github.com/JE-Chen/je_editor/actions/workflows/je-editor-github-actions_dev.yml)

[![JE_Editor GitHub Actions Stable](https://github.com/JE-Chen/je_editor/actions/workflows/je-editor-github-actions_stable.yml/badge.svg?branch=main)](https://github.com/JE-Chen/je_editor/actions/workflows/je-editor-github-actions_stable.yml)

### Document

[![Documentation Status](https://readthedocs.org/projects/je-editor/badge/?version=latest)](https://je-editor.readthedocs.io/en/latest/?badge=latest)

---


![Editor Picture](image/JEditor.png)
> * Project Kanban https://github.com/orgs/Intergration-Automation-Testing/projects/2
> * JEditor is a simple text editor, but it has all the necessary features.
> * JEditor is one of the components of ITE, but modularization allows it to be used separately.
> * JEditor defaults to using a dark interface as shown below:
>> * JEditor has the following features:
>>    * Font change.
>>    * Font size change.
>>    * Auto-save (after first save or open).
>>    * Tree file structure browsing.
>>    * Save and open files.
>>    * Python formatting check using yapf.
>>    * Run python programs.
>>    * Run shell commands.

---

## Requires

```
python 3.8 or later
```

## install

```commandline
pip install je_editor
```

* Test on
    * windows 10 ~ 11
    * osx 10.5 ~ 11 big sur
    * ubuntu 20.0.4
    * raspberry pi 3B+

| All test in test dir

### Architecture Diagram
![Architecture Diagram](architecture_diagram/JEditor_Architecture.drawio.png)